@@ -742,7 +742,8 @@ class Application:
                 # tx.host.kv = kv.db(tx.request.uri.host, ":", {"jobs": "list"})
                 # cache_db = sqlyte.db(f"cache-{tx.request.uri.host}.db", cache.model)
                 # tx.host.cache = cache(db=cache_db)
-                tx.host.db = sqlyte.db(f"site-{tx.request.uri.host}.db", *models)
+                tx.host.db = sqlyte.db(f"site.db", *models)
+                # tx.host.db = sqlyte.db(f"site-{tx.request.uri.host}.db", *models)
                 yield
 
             self.wrappers.insert(0, resume_session)  # 2nd position
